summaryrefslogtreecommitdiffstats
path: root/kreversi/kreversi.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:47:36 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:47:36 -0600
commit97d1732e257f8700488d7ca1660ae7eba8fc6065 (patch)
tree4c6397ed2c1dd6f7c3354b5b87f313547d92a35f /kreversi/kreversi.cpp
parent9c27a1a03e02fd53aedc1a182444b35fd8e14967 (diff)
downloadtdegames-97d1732e257f8700488d7ca1660ae7eba8fc6065.tar.gz
tdegames-97d1732e257f8700488d7ca1660ae7eba8fc6065.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'kreversi/kreversi.cpp')
-rw-r--r--kreversi/kreversi.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/kreversi/kreversi.cpp b/kreversi/kreversi.cpp
index 4c72251b..60d555f3 100644
--- a/kreversi/kreversi.cpp
+++ b/kreversi/kreversi.cpp
@@ -39,7 +39,7 @@
#include <unistd.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqlabel.h>
#include <tqlistbox.h>
@@ -329,9 +329,9 @@ void KReversi::slotUndo()
}
if (m_game->toMove() == computerColor()) {
// Must tqrepaint so that the new move is not shown before the old
// one is removed on the screen.
- m_gameView->tqrepaint();
+ m_gameView->repaint();
computerMakeMove();
}
else
@@ -609,21 +609,21 @@ void KReversi::showGameOver(Color color)
if ( color == Nobody ) {
KNotifyClient::event(winId(), "draw", i18n("Draw!"));
TQString s = i18n("Game is drawn!\n\nYou : %1\nComputer: %2")
- .tqarg(human).tqarg(computer);
+ .arg(human).arg(computer);
KMessageBox::information(this, s, i18n("Game Ended"));
score.setType(KExtHighscore::Draw);
}
else if ( humanColor() == color ) {
KNotifyClient::event(winId(), "won", i18n("Game won!"));
TQString s = i18n("Congratulations, you have won!\n\nYou : %1\nComputer: %2")
- .tqarg(human).tqarg(computer);
+ .arg(human).arg(computer);
KMessageBox::information(this, s, i18n("Game Ended"));
score.setType(KExtHighscore::Won);
}
else {
KNotifyClient::event(winId(), "lost", i18n("Game lost!"));
TQString s = i18n("You have lost the game!\n\nYou : %1\nComputer: %2")
- .tqarg(human).tqarg(computer);
+ .arg(human).arg(computer);
KMessageBox::information(this, s, i18n("Game Ended"));
score.setType(KExtHighscore::Lost);
}
@@ -329,9 +329,9 @@ void KReversi::slotUndo()
}
if (m_game->toMove() == computerColor()) {
- // Must tqrepaint so that the new move is not shown before the old
+ // Must repaint so that the new move is not shown before the old
// one is removed on the screen.